@@ -7,13 +7,15 @@
 # for license details.
 """
 """
-from . import (base,
+from . import (constants,
+               base,
                utils,
                chemicals,
                exceptions,
                functional,
                units_of_measure,
                separations,
+               functors,
 )
 from ._chemical import Chemical
 from ._chemicals import Chemicals, CompiledChemicals
@@ -33,8 +35,8 @@ from flexsolve import speed_up
 
 __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
            'Stream', 'MultiStream', 'ThermalCondition', 'mixture', 'ThermoData',
-           'settings', 'functor', 'chemicals', 'base', 'equilibrium',
-           'units_of_measure', 'exceptions', 'functional', 'reaction',
+           'settings', 'functor', 'functors', 'chemicals', 'base', 'equilibrium',
+           'units_of_measure', 'exceptions', 'functional', 'reaction', 'constants',
            'utils', 'separations', 'speed_up')
 
 # Set number of digits displayed
@@ -48,4 +50,4 @@ pd.set_option('display.max_columns', 10)
 pd.set_option('max_colwidth', 35)
 del np, pd
 
-__version__ = "0.20.23"
\ No newline at end of file
+__version__ = "0.21.5"
\ No newline at end of file
