@@ -17,6 +17,24 @@ import numpy as np
 
 __all__ = ('MultiStream', )
 
+def get_phase_fraction(stream, phases):
+    all_phases = stream.phases
+    phase_fraction = 0.
+    F_mol = stream.F_mol
+    imol = stream.imol
+    if not F_mol: return 0.
+    for phase in phases:
+        if phase in all_phases:
+            phase_fraction += imol[phase].sum() 
+    return phase_fraction / F_mol
+
+def phase_is_present(stream, phases):
+    all_phases = stream.phases
+    imol = stream.imol
+    for phase in phases:
+        if phase in all_phases and imol[phase].any(): return True
+    return False
+
 class MultiStream(Stream):
     """
     Create a MultiStream object that defines material flow rates for multiple
@@ -185,7 +203,8 @@ class MultiStream(Stream):
         self._sink = self._source = None
         self._init_cache()
         self._register(ID)
-        
+        self._link = None
+            
     def _init_indexer(self, flow, phases, chemicals, phase_flows):
         if flow == ():
             if phase_flows:
@@ -212,6 +231,9 @@ class MultiStream(Stream):
         self._lle_cache = eq.LLECache(self._imol,
                                       self._thermal_condition, 
                                       self._thermo)
+        self._sle_cache = eq.SLECache(self._imol,
+                                      self._thermal_condition, 
+                                      self._thermo)
         
     def __getitem__(self, phase):
         streams = self._streams
@@ -219,11 +241,12 @@ class MultiStream(Stream):
             stream = streams[phase]
         else:
             stream = Stream.__new__(Stream)
-            stream._sink = stream._source = None
+            stream._ID = stream._link = stream._sink = stream._source = None
             stream._imol = self._imol.get_phase(phase)
-            stream._ID = None
             stream._thermal_condition = self._thermal_condition
             stream._thermo = self._thermo
+            stream._bubble_point_cache =  self._bubble_point_cache
+            stream._dew_point_cache = self._dew_point_cache
             streams[phase] = stream
         return stream
     
@@ -297,6 +320,7 @@ class MultiStream(Stream):
             self.phase = phases[0]
         phases = sorted(phases)
         if phases != self.phases:
+            if self._link: raise RuntimeError('cannot convert linked stream')
             self._imol = self._imol.to_material_indexer(phases)
             self._init_cache()
     
@@ -333,7 +357,7 @@ class MultiStream(Stream):
 
     @property
     def S(self):
-        """[float] Entropy flow rate in kJ/hr."""
+        """[float] Absolute entropy flow rate in kJ/hr."""
         return self.mixture.xS(self._imol, *self._thermal_condition)
     @property
     def C(self):
@@ -359,11 +383,15 @@ class MultiStream(Stream):
     @property
     def vapor_fraction(self):
         """Molar vapor fraction."""
-        if 'g' in self.phases:
-            vapor_fraction = self.imol['g'].sum() / self.F_mol
-        else:
-            vapor_fraction = 0.
-        return vapor_fraction
+        return get_phase_fraction(self, 'gG')
+    @property
+    def liquid_fraction(self):
+        """Molar liquid fraction."""
+        return get_phase_fraction(self, 'lL')
+    @property
+    def solid_fraction(self):
+        """Molar solid fraction."""
+        return get_phase_fraction(self, 'sS')
     
     @property
     def V(self):
@@ -724,17 +752,29 @@ class MultiStream(Stream):
     def lle(self):
         """[LLE] An object that can perform liquid-liquid equilibrium on the stream."""
         return self._lle_cache.retrieve()
+    @property
+    def sle(self):
+        """[SLE] An object that can perform solid-liquid equilibrium on the stream."""
+        return self._sle_cache.retrieve()
     
     ### Casting ###
     
+    def as_stream(self):
+        """Convert MultiStream to Stream."""
+        phase = self.phase
+        if len(phase) == 1:
+            self.phase = phase
+        else:
+            raise RuntimeError('multiple phases present; cannot convert to single phase stream')
+    
     @property
     def phase(self):
-        return "".join(self._imol._phases)
+        return ''.join([phases[0] for phases in ('gG', 'lL', 'sS')  if phase_is_present(self, phases)])
     @phase.setter
     def phase(self, phase):
-        assert len(phase) == 1, f'invalid phase {repr(phase)}'
-        self.__class__ = Stream
+        if self._link: raise RuntimeError('cannot convert linked stream')
         self._imol = self._imol.to_chemical_indexer(phase)
+        self.__class__ = Stream
     
     ### Representation ###
     
