@@ -78,6 +78,12 @@ class Stream:
      phase: 'l', T: 298.15 K, P: 101325 Pa
      flow (kg/hr): Water    20
                    Ethanol  10
+    >>> s1.show(composition=True, flow='kg/hr') # Its also possible to show by composition
+    Stream: s1
+     phase: 'l', T: 298.15 K, P: 101325 Pa
+     composition: Water    0.667
+                  Ethanol  0.333
+                  -------  30 kg/hr
     
     All flow rates are stored as an array in the `mol` attribute:
     
@@ -189,7 +195,7 @@ class Stream:
                      (l) Water    0.6381
                          Ethanol  0.02552
     
-    Note that the stream is a now a MultiStream to manage multiple phases.
+    Note that the stream is a now a MultiStream object to manage multiple phases.
     Each phase can be accessed separately too:
     
     >>> s1['l'].show()
@@ -204,11 +210,20 @@ class Stream:
      flow (kmol/hr): Water    0.472
                      Ethanol  0.192
     
+    We can convert a MultiStream object back to a Stream object by setting the phase:
+        
+    >>> s1.phase = 'l'
+    >>> s1.show(flow='kg/hr')
+    Stream: s1
+     phase: 'l', T: 364.8 K, P: 101325 Pa
+     flow (kg/hr): Water    20
+                   Ethanol  10
+    
     """
     __slots__ = ('_ID', '_imol', '_thermal_condition', '_thermo', '_streams',
                  '_bubble_point_cache', '_dew_point_cache',
-                 '_vle_cache', '_lle_cache',
-                 '_sink', '_source', '_price')
+                 '_vle_cache', '_lle_cache', '_sle_cache',
+                 '_sink', '_source', '_price', '_link')
     line = 'Stream'
     
     #: [DisplayUnits] Units of measure for IPython display (class attribute)
@@ -232,6 +247,10 @@ class Stream:
         self._sink = self._source = None # For BioSTEAM
         self._init_cache()
         self._register(ID)
+        self._link = None
+
+    def as_stream(self):
+        """Does nothing."""
 
     @property
     def price(self):
@@ -259,7 +278,15 @@ class Stream:
     @property
     def vapor_fraction(self):
         """Molar vapor fraction."""
-        return 1.0 if self.phase.lower() == 'g' else 0.0
+        return 1.0 if self.phase in 'gG' else 0.0
+    @property
+    def liquid_fraction(self):
+        """Molar liquid fraction."""
+        return 1.0 if self.phase in 'lL' else 0.0
+    @property
+    def solid_fraction(self):
+        """Molar solid fraction."""
+        return 1.0 if self.phase in 'sS' else 0.0
 
     def isfeed(self):
         """Return whether stream has a sink but no source."""
@@ -282,7 +309,7 @@ class Stream:
             ins = sink.ins
             index = ins.index(self)
             ins[index] = None
-        else:
+        if source:
             outs = source.outs
             index = outs.index(self)
             outs[index] = None
@@ -326,8 +353,9 @@ class Stream:
                 name = 'vol'
                 factor = vol_units.conversion_factor(units)
             else:
-                raise DimensionError(f"dimensions for flow units must be in molar, "
-                                     f"mass or volumetric flow rates, not '{dimensionality}'")
+                raise DimensionError("dimensions for flow units must be in molar, "
+                                     "mass or volumetric flow rates, not "
+                                    f"'{dimensionality}'")
             cache[units] = name, factor
         return name, factor
 
@@ -485,7 +513,7 @@ class Stream:
         if name in units_dct:
             original_units = units_dct[name]
         else:
-            raise ValueError(f"no property with name '{name}'")
+            raise ValueError(f"'{name}' is not thermodynamic property")
         return original_units.convert(value, units)
     
     def set_property(self, name, value, units):
@@ -650,7 +678,7 @@ class Stream:
 
     @property
     def S(self):
-        """[float] Entropy flow rate in kJ/hr."""
+        """[float] Absolute entropy flow rate in kJ/hr."""
         return self.mixture.S(self.phase, self.mol, *self._thermal_condition)
     
     @property
@@ -699,7 +727,7 @@ class Stream:
     @property
     def z_vol(self):
         """[1d array] Volumetric composition."""
-        vol = self.vol.value
+        vol = 1. * self.vol
         z = vol / vol.sum()
         z.setflags(0)
         return z
@@ -746,7 +774,7 @@ class Stream:
     @property
     def alpha(self):
         """[float] Thermal diffusivity [m^2/s]."""
-        return fn.thermal_diffusivity(self.kappa, self.rho, self.Cp)
+        return fn.alpha(self.kappa, self.rho, self.Cp * 1000.)
     @property
     def rho(self):
         """[float] Density [kg/m^3]."""
@@ -758,7 +786,7 @@ class Stream:
     @property
     def Pr(self):
         """[float] Prandtl number [-]."""
-        return fn.Pr(self.Cp, self.mu, self.k)
+        return fn.Pr(self.Cp * 1000, self.kappa, self.mu)
     
     ### Stream methods ###
     
@@ -791,6 +819,8 @@ class Stream:
         
         Examples
         --------
+        Sum two streams:
+        
         >>> import thermosteam as tmo
         >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
@@ -801,6 +831,15 @@ class Stream:
          flow (kg/hr): Water    40
                        Ethanol  20
         
+        Sum two streams with new property package:
+            
+        >>> thermo = tmo.Thermo(['Water', 'Ethanol', 'Methanol'], cache=True)
+        >>> s_sum = tmo.Stream.sum([s1, s1], 's_sum', thermo)
+        >>> s_sum.show(flow='kg/hr')
+        Stream: s_sum
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kg/hr): Water    40
+                       Ethanol  20
         """
         if streams:
             new = streams[0].copy(ID)
@@ -856,17 +895,20 @@ class Stream:
             self._imol.mix_from([i._imol for i in others])
             H = sum([i.H for i in others])
             try: self.H = H
-            except Exception as error:
-                phase = self.phase.lower()
-                if phase == 'g':
-                     # Maybe too much heat, gas must be present
-                    self.phase = 'l'
-                elif phase == 'l':
-                    # Maybe too little heat, liquid must be present
-                    self.phase = 'g'
+            except Exception as error: # pragma: no cover
+                if self.isempty():
+                    self.T = np.mean([i.T for i in others])
                 else:
-                    raise error
-                self.H = H
+                    phase = self.phase.lower()
+                    if phase == 'g':
+                         # Maybe too much heat, gas must be present
+                        self.phase = 'l'
+                    elif phase == 'l':
+                        # Maybe too little heat, liquid must be present
+                        self.phase = 'g'
+                    else:
+                        raise error
+                    self.H = H
             
     def split_to(self, s1, s2, split):
         """
@@ -931,8 +973,14 @@ class Stream:
         'g'
         
         """
-        assert isinstance(other._imol, self._imol.__class__), "other must be of same type to link with"
-        
+        if not isinstance(other._imol, self._imol.__class__):
+            at_unit = f"at unit {self.source}" if self.source is other.sink else ""
+            raise RuntimeError(f"stream {self} cannot link with stream {other} " + at_unit
+                               + "; streams must have the same class to link")
+        if self._link and not (self.source is other.sink or self.sink is other.source):
+            at_unit = f"at unit {self.source}" if self.source is other.sink else ""
+            raise RuntimeError(f"stream {self} cannot link with stream {other} " + at_unit
+                               + f"; {self} already linked with {self._link}")
         if TP and flow and phase:
             self._imol._data_cache = other._imol._data_cache
         else:
@@ -944,6 +992,9 @@ class Stream:
             self._imol._data = other._imol._data
         if phase:
             self._imol._phase = other._imol._phase
+        
+        self._link = other
+        other._link = self
             
     def unlink(self):
         """
@@ -966,6 +1017,7 @@ class Stream:
         self._imol._data = self._imol._data.copy()
         self._imol._phase = self._imol._phase.copy()
         self._init_cache()
+        self._link = None
     
     def copy_like(self, other):
         """
@@ -999,8 +1051,16 @@ class Stream:
          flow (kg/hr): Water  2
 
         """
-        if isinstance(other, tmo.MultiStream): self.phases = other.phases
-        self._imol.copy_like(other._imol)
+        if isinstance(other, tmo.MultiStream):
+            phase = other.phase
+            if len(phase) == 1:
+                imol = other._imol.to_chemical_indexer(phase)
+            else:
+                self.phases = other.phases
+                imol = other._imol
+        else:
+            imol = other._imol
+        self._imol.copy_like(imol)
         self._thermal_condition.copy_like(other._thermal_condition)
     
     def copy_thermal_condition(self, other):
@@ -1075,11 +1135,31 @@ class Stream:
         Cut and paste flows:
         
         >>> s2.copy_flow(s1, remove=True)
+        >>> s2.show(flow='kg/hr')
+        Stream: s2
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kg/hr): Water    20
+                       Ethanol  10
+        
         >>> s1.show()
         Stream: s1
          phase: 'l', T: 298.15 K, P: 101325 Pa
          flow: 0
          
+        Its also possible to copy flows from a multistream:
+        
+        >>> s1.phases = ('g', 'l')
+        >>> s1.imol['g', 'Water'] = 10
+        >>> s2.copy_flow(s1, remove=True)
+        >>> s2.show()
+        Stream: s2
+         phase: 'l', T: 298.15 K, P: 101325 Pa
+         flow (kmol/hr): Water  10
+        >>> s1.show()
+        MultiStream: s1
+         phases: ('g', 'l'), T: 298.15 K, P: 101325 Pa
+         flow: 0
+         
         """
         chemicals = self.chemicals
         mol = stream.mol
@@ -1093,7 +1173,7 @@ class Stream:
         self.mol[index] = mol[index]
         if remove: 
             if isinstance(stream, tmo.MultiStream):
-                mol[..., index] = 0
+                stream.imol.data[:, index] = 0
             else:
                 mol[index] = 0
     
@@ -1122,7 +1202,7 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
-        new._sink = new._source = None
+        new._link = new._sink = new._source = None
         new._thermo = self._thermo
         new._imol = self._imol.copy()
         new._thermal_condition = self._thermal_condition.copy()
@@ -1148,14 +1228,14 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
-        new.ID = None
-        new._sink = new._source = None
+        new.ID = new._sink = new._source = None
         new.price = 0
         new._thermo = self._thermo
         new._imol = imol = self._imol._copy_without_data()
         imol._data = self._imol._data
         new._thermal_condition = self._thermal_condition.copy()
         new._init_cache()
+        new._link = self
         return new
     
     def proxy(self, ID=None):
@@ -1182,6 +1262,7 @@ class Stream:
         new._thermal_condition = self._thermal_condition
         try: new._vle_cache = self._vle_cache
         except AttributeError: pass
+        new._link = self
         return new
     
     def empty(self):
@@ -1212,6 +1293,12 @@ class Stream:
         """[LLE] An object that can perform liquid-liquid equilibrium on the stream."""
         self.phases = ('L', 'l')
         return self.lle
+    
+    @property
+    def sle(self):
+        """[SLE] An object that can perform solid-liquid equilibrium on the stream."""
+        self.phases = ('s', 'l')
+        return self.sle
 
     @property
     def vle_chemicals(self):
@@ -1586,12 +1673,21 @@ class Stream:
         
     ### Casting ###
     
+    @property
+    def link(self):
+        """
+        [Stream] Data on the thermal condition and material flow rates may 
+        be shared with this stream.
+        """
+        return self._link
+    
     @property
     def phases(self):
         """tuple[str] All phases present."""
         return (self.phase,)
     @phases.setter
     def phases(self, phases):
+        if self._link: raise RuntimeError('cannot convert linked stream')
         if len(phases) == 1:
             self.phase = phases[0]
         else:
@@ -1606,6 +1702,9 @@ class Stream:
             self._lle_cache = eq.LLECache(self._imol,
                                           self._thermal_condition,
                                           self._thermo)
+            self._sle_cache = eq.SLECache(self._imol,
+                                          self._thermal_condition,
+                                          self._thermo)
     
     ### Representation ###
     
@@ -1699,10 +1798,15 @@ class Stream:
         print(self._info(T, P, flow, composition, N))
     _ipython_display_ = show
     
-    def print(self):
+    def print(self, units=None):
         """
         Print in a format that you can use recreate the stream.
         
+        Parameters
+        ----------
+        units : str, optional
+            Units of measure for material flow rates. Defaults to 'kmol/hr'
+        
         Examples
         --------
         >>> import thermosteam as tmo
@@ -1710,11 +1814,18 @@ class Stream:
         >>> s1 = tmo.Stream(ID='s1',
         ...                 Water=20, Ethanol=10, units='kg/hr',
         ...                 T=298.15, P=101325, phase='l')
-        >>> s1.print()
-        Stream(ID='s1', phase='l', T=298.15, P=101325, Water=1.11, Ethanol=0.2171)
+        >>> s1.print(units='kg/hr')
+        Stream(ID='s1', phase='l', T=298.15, P=101325, Water=20, Ethanol=10, units='kg/hr')
+        >>> s1.print() # Units default to kmol/hr
+        Stream(ID='s1', phase='l', T=298.15, P=101325, Water=1.11, Ethanol=0.2171, units='kmol/hr')
         
         """
-        chemical_flows = utils.repr_IDs_data(self.chemicals.IDs, self.mol)
+        if not units:
+            units = 'kmol/hr'
+            flow = self.mol
+        else:
+            flow = self.get_flow(units)
+        chemical_flows = utils.repr_IDs_data(self.chemicals.IDs, flow)
         price = utils.repr_kwarg('price', self.price)
         print(f"{type(self).__name__}(ID={repr(self.ID)}, phase={repr(self.phase)}, T={self.T:.2f}, "
-              f"P={self.P:.6g}{price}{chemical_flows})")
+              f"P={self.P:.6g}{price}{chemical_flows}, units={repr(units)})")
