@@ -9,9 +9,9 @@
 """
 from .thermo_model_handle import TDependentModelHandle, TPDependentModelHandle
 from .functor import functor_lookalike
-from ..utils import read_only
+from ..utils import read_only, cucumber
 
-__all__ = ('PhaseHandle', #'PhaseHandleBuilder', 
+__all__ = ('PhaseHandle',
            'PhaseTHandle', 'PhaseTPHandle',
            'PhaseTHandleBuilder', 'PhaseTPHandleBuilder',
            'PhaseMixtureHandle',
@@ -22,6 +22,7 @@ __all__ = ('PhaseHandle', #'PhaseHandleBuilder',
 
 # %% Abstract class    
 
+@cucumber
 @read_only
 @functor_lookalike
 class PhaseHandle:
@@ -138,6 +139,7 @@ class PhaseHandleBuilder:
                 builder.build(handle, *data)
         return phase_handle
 
+
 class PhaseTHandleBuilder(PhaseHandleBuilder):
     __slots__ = ()
     PhaseHandle = PhaseTHandle
@@ -147,6 +149,7 @@ class PhaseTPHandleBuilder(PhaseHandleBuilder):
     __slots__ = ()
     PhaseHandle = PhaseTPHandle
         
+    
 class PhaseFunctorBuilder:
     __slots__ = ('var', 's', 'l', 'g', 'build_functors')
     
@@ -168,6 +171,7 @@ class PhaseFunctorBuilder:
                 setfield(phase_handle, phase, functor)
         return phase_handle
 
+
 class PhaseTFunctorBuilder(PhaseFunctorBuilder):
     __slots__ = ()
     PhaseHandle = PhaseTHandle
