@@ -48,7 +48,7 @@ class BubblePoint:
     Examples
     --------
     >>> import thermosteam as tmo
-    >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+    >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
     >>> tmo.settings.set_thermo(chemicals)
     >>> BP = tmo.equilibrium.BubblePoint(chemicals)
     >>> molar_composition = (0.5, 0.5)
@@ -71,7 +71,7 @@ class BubblePoint:
     def __init__(self, chemicals=(), thermo=None):
         thermo = settings.get_default_thermo(thermo)
         chemicals = tuple(chemicals)
-        key = (chemicals, thermo)
+        key = (chemicals, thermo.Gamma, thermo.Phi, thermo.PCF)
         cached = self._cached
         if key in cached:
             other = cached[key]
@@ -156,11 +156,11 @@ class BubblePoint:
         --------
         >>> import thermosteam as tmo
         >>> import numpy as np
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
         >>> BP.solve_Ty(z=np.array([0.6, 0.4]), P=101325)
-        (353.75434459553634, array([0.381, 0.619]))
+        (353.7543, array([0.381, 0.619]))
         
         """
         self.P = P
@@ -204,11 +204,11 @@ class BubblePoint:
         --------
         >>> import thermosteam as tmo
         >>> import numpy as np
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
+        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'], cache=True)
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
         >>> BP.solve_Py(z=np.array([0.703, 0.297]), T=352.28)
-        (91830.97988957872, array([0.419, 0.581]))
+        (91830.9798, array([0.419, 0.581]))
         
         """
         self.T = T
