@@ -33,9 +33,12 @@ _new = object.__new__
 
 def find_main_phase(indexers, default):
     main_indexer, *indexers = indexers
-    phase = main_indexer.phase
-    for i in indexers:
-        if phase != i.phase: return default
+    try:
+        phase = main_indexer.phase
+        for i in indexers:
+            if phase != i.phase: return default
+    except:
+        return default
     return phase
 
 def nonzeros(IDs, data):
@@ -495,11 +498,8 @@ class MaterialIndexer(Indexer):
                 index = self._get_index(key)
             else:
                 index = ChemicalIndex(index)
-            if len(cache) > 1000:
-                for i in cache: # pragma: no cover
-                    del cache[i]
-                    break
             cache[key] = index
+            utils.trim_cache(cache)
         except TypeError:
             raise TypeError("only strings, tuples, and ellipsis are valid index keys")
         return index
